@@ -11,7 +11,7 @@ See `CircuitPython:board` in CircuitPython for more details.
 """
 
 
-__version__ = "8.45.0"
+__version__ = "8.48.0"
 __repo__ = "https://github.com/adafruit/Adafruit_Blinka.git"
 __blinka__ = True
 
@@ -26,6 +26,9 @@ from adafruit_blinka.agnostic import board_id, detector
 if board_id == ap_board.FEATHER_HUZZAH:
     from adafruit_blinka.board.feather_huzzah import *
 
+elif board_id == ap_board.VISIONFIVE2:
+    from adafruit_blinka.board.starfive.visionfive2 import *
+
 elif board_id == ap_board.OLIMEX_LIME2:
     from adafruit_blinka.board.OLIMEX_LIME2 import *
 
@@ -149,9 +152,18 @@ elif board_id == ap_board.BANANA_PI_M2_ZERO:
 elif board_id == ap_board.BANANA_PI_M2_PLUS:
     from adafruit_blinka.board.bananapi.bpim2plus import *
 
+elif board_id == ap_board.BANANA_PI_M4_BERRY:
+    from adafruit_blinka.board.bananapi.bpim4berry import *
+
+elif board_id == ap_board.BANANA_PI_M4_ZERO:
+    from adafruit_blinka.board.bananapi.bpim4zero import *
+
 elif board_id == ap_board.BANANA_PI_M5:
     from adafruit_blinka.board.bananapi.bpim5 import *
 
+elif board_id == ap_board.BANANA_PI_F3:
+    from adafruit_blinka.board.bananapi.bpif3 import *
+
 elif board_id == ap_board.LEMAKER_BANANA_PRO:
     from adafruit_blinka.board.lemaker.bananapro import *
 
@@ -401,6 +413,9 @@ elif board_id == ap_board.MILKV_DUO:
 elif board_id == ap_board.WALNUT_PI_1B:
     from adafruit_blinka.board.walnutpi.walnutpi1b import *
 
+elif board_id == ap_board.RP2040_ONE_U2IF:
+    from adafruit_blinka.board.rp2040_one_u2if import *
+
 elif board_id == ap_board.OS_AGNOSTIC_BOARD:
     from adafruit_blinka.board.generic_agnostic_board import *
 
@@ -416,6 +431,12 @@ elif board_id == ap_board.LUCKFOX_PICO_PLUS:
 elif board_id == ap_board.LUCKFOX_PICO_MAX:
     from adafruit_blinka.board.luckfox.luckfoxpico_max import *
 
+elif board_id == ap_board.VIVID_UNIT:
+    from adafruit_blinka.board.vivid_unit import *
+
+elif board_id == ap_board.INDIEDROID_NOVA:
+    from adafruit_blinka.board.ameridroid.indiedroid_nova import *
+
 elif "sphinx" in sys.modules:
     pass
 
