@@ -18,6 +18,8 @@ from adafruit_blinka.agnostic import detector
 
 if detector.board.any_raspberry_pi:
     from adafruit_blinka.microcontroller.bcm283x.pwmio.PWMOut import PWMOut
+elif detector.board.any_bananapi:
+    from adafruit_blinka.microcontroller.generic_linux.sysfs_pwmout import PWMOut
 elif detector.board.any_coral_board:
     from adafruit_blinka.microcontroller.generic_linux.sysfs_pwmout import PWMOut
 elif detector.board.any_giant_board:
@@ -46,6 +48,8 @@ elif detector.board.any_jetson_board:
     from adafruit_blinka.microcontroller.tegra.PWMOut import PWMOut
 elif detector.board.any_luckfox_pico_board:
     from adafruit_blinka.microcontroller.generic_linux.sysfs_pwmout import PWMOut
+elif detector.board.any_starfive_id:
+    from adafruit_blinka.microcontroller.starfive.JH7110.pwmio import PWMOut
 elif detector.board.OS_AGNOSTIC_BOARD:
     from adafruit_blinka.microcontroller.generic_agnostic_board.PWMOut import PWMOut
 elif (
